@@ -12,6 +12,7 @@ from keyring.backend import NullCrypter
 from keyring import errors
 from . import mocks
 
+
 def is_gdata_supported():
     try:
         __import__('gdata.service')
@@ -19,16 +20,19 @@ def is_gdata_supported():
         return False
     return True
 
+
 def init_google_docs_keyring(client, can_create=True,
                              input_getter=input):
     credentials = SimpleCredential('foo', 'bar')
-    return Google.DocsKeyring(credentials,
-                                             'test_src',
-                                             NullCrypter(),
-                                             client=client,
-                                             can_create=can_create,
-                                             input_getter=input_getter
-                                            )
+    return Google.DocsKeyring(
+        credentials,
+        'test_src',
+        NullCrypter(),
+        client=client,
+        can_create=can_create,
+        input_getter=input_getter
+    )
+
 
 @unittest.skipUnless(is_gdata_supported(),
                      "Need Google Docs (gdata)")
@@ -40,6 +44,7 @@ class GoogleDocsKeyringTestCase(BackendBasicTests, unittest.TestCase):
         client.SetClientLoginToken('foo')
         return init_google_docs_keyring(client)
 
+
 @unittest.skipUnless(is_gdata_supported(),
                      "Need Google Docs (gdata)")
 class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
@@ -58,7 +63,7 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
         listfeed = mocks.MockListFeed()
         listfeed._entry = [mocks.MockDocumentListEntry(),
                            mocks.MockDocumentListEntry()
-                          ]
+                           ]
         return listfeed
 
     def _encode_data(self, data):
@@ -87,11 +92,13 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
         client.captcha_url = 'a_captcha_url'
         client.captcha_token = 'token'
         self.get_input_called = False
+
         def _get_input(prompt):
             self.get_input_called = True
             delattr(client, '_login_err')
             return 'Foo'
-        self.keyring = init_google_docs_keyring(client, input_getter=_get_input)
+        self.keyring = init_google_docs_keyring(
+            client, input_getter=_get_input)
         self.keyring.client
         self.assertTrue(self.get_input_called, 'Should have got input')
 
@@ -102,12 +109,14 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
         client._request_response = dict(status=200, data=no_utf8_bom_entries)
         client._listfeed = self._init_listfeed()
         self._init_keyring(client)
-        self.assertEqual(self.keyring.get_password('section1', 'user1'), 'pwd1')
+        self.assertEqual(
+            self.keyring.get_password('section1', 'user1'), 'pwd1')
 
         utf8_bom_entries = codecs.BOM_UTF8 + no_utf8_bom_entries
         client._request_response = dict(status=200, data=utf8_bom_entries)
         self._init_keyring(client)
-        self.assertEqual(self.keyring.get_password('section1', 'user1'), 'pwd1')
+        self.assertEqual(
+            self.keyring.get_password('section1', 'user1'), 'pwd1')
 
     def test_handles_retrieve_failure(self):
         client = self._init_client()
@@ -115,64 +124,76 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
         client._request_response = dict(status=400,
                                         reason='Data centre explosion')
         self._init_keyring(client)
-        self.assertRaises(errors.InitError, self.keyring.get_password, 'any', 'thing')
+        self.assertRaises(
+            errors.InitError, self.keyring.get_password, 'any', 'thing')
 
     def test_handles_corrupt_retrieve(self):
         client = self._init_client()
         dummy_entries = dict(section1=dict(user1='pwd1'))
-        client._request_response = dict(status=200, data='broken' + self._encode_data(dummy_entries))
+        client._request_response = dict(
+            status=200, data='broken' + self._encode_data(dummy_entries))
         client._listfeed = self._init_listfeed()
         self._init_keyring(client)
-        self.assertRaises(errors.InitError, self.keyring.get_password, 'any', 'thing')
+        self.assertRaises(
+            errors.InitError, self.keyring.get_password, 'any', 'thing')
 
     def test_no_create_if_requested(self):
         client = self._init_client()
         self.keyring = init_google_docs_keyring(client, can_create=False)
-        self.assertRaises(errors.InitError, self.keyring.get_password, 'any', 'thing')
+        self.assertRaises(
+            errors.InitError, self.keyring.get_password, 'any', 'thing')
 
     def test_no_set_if_create_folder_fails_on_new_keyring(self):
         import gdata
         client = self._init_client()
         client._create_folder_err = gdata.service.RequestError
         self._init_keyring(client)
-        self.assertEqual(self.keyring.get_password('service-a', 'user-A'), None,
-                        'No password should be set in new keyring')
+        self.assertEqual(
+            self.keyring.get_password('service-a', 'user-A'), None,
+            'No password should be set in new keyring')
         self.assertRaises(errors.PasswordSetError, self.keyring.set_password,
                           'service-a', 'user-A', 'password-A')
-        self.assertEqual(self.keyring.get_password('service-a', 'user-A'), None,
-                        'No password should be set after write fail')
+        self.assertEqual(
+            self.keyring.get_password('service-a', 'user-A'), None,
+            'No password should be set after write fail')
 
     def test_no_set_if_write_fails_on_new_keyring(self):
         import gdata
         client = self._init_client()
         client._upload_err = gdata.service.RequestError
         self._init_keyring(client)
-        self.assertEqual(self.keyring.get_password('service-a', 'user-A'), None,
-                        'No password should be set in new keyring')
+        self.assertEqual(
+            self.keyring.get_password('service-a', 'user-A'), None,
+            'No password should be set in new keyring')
         self.assertRaises(errors.PasswordSetError, self.keyring.set_password,
                           'service-a', 'user-A', 'password-A')
-        self.assertEqual(self.keyring.get_password('service-a', 'user-A'), None,
-                        'No password should be set after write fail')
+        self.assertEqual(
+            self.keyring.get_password('service-a', 'user-A'), None,
+            'No password should be set after write fail')
 
     def test_no_set_if_write_fails_on_existing_keyring(self):
         import gdata
         client = self._init_client()
         dummy_entries = dict(sectionB=dict(user9='pwd9'))
-        client._request_response = dict(status=200, data=self._encode_data(dummy_entries))
+        client._request_response = dict(
+            status=200, data=self._encode_data(dummy_entries))
         client._put_err = gdata.service.RequestError
         client._listfeed = self._init_listfeed()
         self._init_keyring(client)
-        self.assertEqual(self.keyring.get_password('sectionB', 'user9'), 'pwd9',
-                        'Correct password should be set in existing keyring')
+        self.assertEqual(
+            self.keyring.get_password('sectionB', 'user9'), 'pwd9',
+            'Correct password should be set in existing keyring')
         self.assertRaises(errors.PasswordSetError, self.keyring.set_password,
                           'sectionB', 'user9', 'Not the same pwd')
-        self.assertEqual(self.keyring.get_password('sectionB', 'user9'), 'pwd9',
-                        'Password should be unchanged after write fail')
+        self.assertEqual(
+            self.keyring.get_password('sectionB', 'user9'), 'pwd9',
+            'Password should be unchanged after write fail')
 
     def test_writes_correct_data_to_google_docs(self):
         client = self._init_client()
         dummy_entries = dict(sectionWriteChk=dict(userWriteChk='pwd'))
-        client._request_response = dict(status=200, data=self._encode_data(dummy_entries))
+        client._request_response = dict(
+            status=200, data=self._encode_data(dummy_entries))
         client._listfeed = self._init_listfeed()
         self._init_keyring(client)
         self.keyring.set_password('sectionWriteChk',
@@ -189,10 +210,12 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
         client = self._init_client()
         dummy_entries = dict(sectionWriteConflictA=dict(
             userwriteConflictA='pwdwriteConflictA'))
-        client._request_response = dict(status=200, data=self._encode_data(dummy_entries))
-        client._put_err = [(gdata.service.RequestError,
-                               {'status': '406',
-                                'reason': 'Conflict'}),]
+        client._request_response = dict(
+            status=200, data=self._encode_data(dummy_entries))
+        client._put_err = [(
+            gdata.service.RequestError,
+            {'status': '406', 'reason': 'Conflict'},
+        )]
         client._listfeed = self._init_listfeed()
         self._init_keyring(client)
         self.assertEqual(
@@ -201,7 +224,8 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
             'pwdwriteConflictA',
             'Correct password should be set in existing keyring')
         dummy_entries['diffSection'] = dict(foo='bar')
-        client._request_response = dict(status=200, data=self._encode_data(dummy_entries))
+        client._request_response = dict(
+            status=200, data=self._encode_data(dummy_entries))
         new_pwd = 'Not the same pwd'
         self.keyring.set_password('sectionWriteConflictA',
                                   'userwriteConflictA',
@@ -210,7 +234,7 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
         self.assertEquals(self.keyring.get_password('sectionWriteConflictA',
                                                     'userwriteConflictA'),
                           new_pwd
-        )
+                          )
         self.assertEqual(1, client._put_count,
                          'Write not called after conflict resolution')
 
@@ -219,10 +243,10 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
         client = self._init_client()
         dummy_entries = dict(sectionWriteConflictB=dict(
             userwriteConflictB='pwdwriteConflictB'))
-        client._request_response = dict(status=200, data=self._encode_data(dummy_entries))
+        client._request_response = dict(
+            status=200, data=self._encode_data(dummy_entries))
         client._put_err = (gdata.service.RequestError,
-                               {'status': '406',
-                                'reason': 'Conflict'})
+                           {'status': '406', 'reason': 'Conflict'})
         client._listfeed = self._init_listfeed()
         self._init_keyring(client)
         self.assertEqual(
@@ -232,19 +256,21 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
             'Correct password should be set in existing keyring')
         conflicting_dummy_entries = dict(sectionWriteConflictB=dict(
             userwriteConflictB='pwdwriteConflictC'))
-        client._request_response = dict(status=200, data=self._encode_data(conflicting_dummy_entries))
-        self.assertRaises(errors.PasswordSetError, self.keyring.set_password,
-                          'sectionWriteConflictB', 'userwriteConflictB', 'new_pwd')
+        client._request_response = dict(
+            status=200, data=self._encode_data(conflicting_dummy_entries))
+        self.assertRaises(
+            errors.PasswordSetError, self.keyring.set_password,
+            'sectionWriteConflictB', 'userwriteConflictB', 'new_pwd')
 
     def test_handles_write_conflict_with_identical_change(self):
         import gdata
         client = self._init_client()
         dummy_entries = dict(sectionWriteConflictC=dict(
             userwriteConflictC='pwdwriteConflictC'))
-        client._request_response = dict(status=200, data=self._encode_data(dummy_entries))
+        client._request_response = dict(
+            status=200, data=self._encode_data(dummy_entries))
         client._put_err = [(gdata.service.RequestError,
-                               {'status': '406',
-                                 'reason': 'Conflict'}),]
+                            {'status': '406', 'reason': 'Conflict'})]
         client._listfeed = self._init_listfeed()
         self._init_keyring(client)
         self.assertEqual(
@@ -255,14 +281,15 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
         new_pwd = 'Not the same pwd'
         conflicting_dummy_entries = dict(sectionWriteConflictC=dict(
             userwriteConflictC=new_pwd))
-        client._request_response = dict(status=200, data=self._encode_data(conflicting_dummy_entries))
+        client._request_response = dict(
+            status=200, data=self._encode_data(conflicting_dummy_entries))
         self.keyring.set_password('sectionWriteConflictC',
                                   'userwriteConflictC',
                                   new_pwd)
         self.assertEquals(self.keyring.get_password('sectionWriteConflictC',
                                                     'userwriteConflictC'),
                           new_pwd
-        )
+                          )
 
     def test_handles_broken_google_put_when_non_owner_update_fails(self):
         """Google Docs has a bug when putting to a non-owner
@@ -272,19 +299,25 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
         client = self._init_client()
         dummy_entries = dict(sectionBrokenPut=dict(
             userBrokenPut='pwdBrokenPut'))
-        client._request_response = dict(status=200, data=self._encode_data(dummy_entries))
+        client._request_response = dict(
+            status=200, data=self._encode_data(dummy_entries))
         client._put_err = [(
             gdata.service.RequestError,
-                { 'status': '400',
-                  'body': 'Sorry, there was an error saving the file. Please try again.',
-                  'reason': 'Bad Request'}),]
+            {
+                'status': '400',
+                'body': 'Sorry, there was an error saving the '
+                'file. Please try again.',
+                'reason': 'Bad Request',
+            }
+        )]
         client._listfeed = self._init_listfeed()
         self._init_keyring(client)
         new_pwd = 'newPwdBrokenPut'
         correct_read_entries = dict(sectionBrokenPut=dict(
             userBrokenPut='pwdBrokenPut'))
-        client._request_response = dict(status=200,
-                                        data=self._encode_data(correct_read_entries))
+        client._request_response = dict(
+            status=200,
+            data=self._encode_data(correct_read_entries))
         self.assertRaises(errors.PasswordSetError, self.keyring.set_password,
                           'sectionBrokenPut', 'userBrokenPut', new_pwd)
 
@@ -296,19 +329,25 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
         client = self._init_client()
         dummy_entries = dict(sectionBrokenPut=dict(
             userBrokenPut='pwdBrokenPut'))
-        client._request_response = dict(status=200, data=self._encode_data(dummy_entries))
+        client._request_response = dict(
+            status=200, data=self._encode_data(dummy_entries))
         client._put_err = [(
             gdata.service.RequestError,
-                { 'status': '400',
-                  'body': 'Sorry, there was an error saving the file. Please try again.',
-                  'reason': 'Bad Request'}),]
+            {
+                'status': '400',
+                'body': 'Sorry, there was an error saving the '
+                'file. Please try again.',
+                'reason': 'Bad Request',
+            }
+        )]
         client._listfeed = self._init_listfeed()
         self._init_keyring(client)
         new_pwd = 'newPwdBrokenPut'
         correct_read_entries = dict(sectionBrokenPut=dict(
             userBrokenPut=new_pwd))
-        client._request_response = dict(status=200,
-                                        data=self._encode_data(correct_read_entries))
+        client._request_response = dict(
+            status=200,
+            data=self._encode_data(correct_read_entries))
         self.keyring.set_password('sectionBrokenPut',
                                   'userBrokenPut',
                                   new_pwd)
@@ -323,8 +362,9 @@ class GoogleDocsKeyringInteractionTestCase(unittest.TestCase):
         client._create_folder_err = gdata.service.RequestError
 
         self._init_keyring(client)
-        self.assertEqual(self.keyring.get_password('service-a', 'user-A'), None,
-                         'No password should be set in new keyring')
+        self.assertEqual(
+            self.keyring.get_password('service-a', 'user-A'), None,
+            'No password should be set in new keyring')
         client._listfeed = self._init_listfeed()
         self.keyring.set_password('service-a', 'user-A', 'password-A')
         self.assertIsNotNone(client._upload_data, 'Should have written data')
