@@ -16,18 +16,6 @@ def is_win32_crypto_supported():
     return sys.platform in ['win32'] and sys.getwindowsversion()[-2] == 2
 
 
-def is_winvault_supported():
-    try:
-        __import__('win32cred')
-        has_pywin32 = True
-    except ImportError:
-        has_pywin32 = False
-    return (
-        sys.platform in ['win32'] and sys.getwindowsversion().major >= 6
-        and has_pywin32
-    )
-
-
 @unittest.skipUnless(is_win32_crypto_supported(),
                      "Need Windows")
 class Win32CryptoKeyringTestCase(FileKeyringTests, unittest.TestCase):
